==> complete_channel_admin1.12_netbots_ed.zip: netset.tcl <==

# Additions by Loki`

# CCA Script Add-on
# Base modules (used by all scripts below)
set nb_component(ccasbase) 1
#nb_set G3neral nb_component(ccasbase) 1
# The channel(s) your bot will monitor (eg "#lamers #mychan #LokiRules #antilame"
  set approved_chans "#Lamer #FTP4Warez #TCL #Egghelp"
# The channel(s) your bot will monitor for onjoins
  set spamcheck_chans "#Lamer"
# If you know the numbers of diffr colors, put them here (for messages and stuff)
  set color1loki 5
  set color2loki 4

#---------------------------------------------------------------------------------------
#  Enable OP Channel Triggers (!kb, !perm, !addserv, !adduser...)
set nb_component(optriggers) 0
nb_set G3neral,m0r0n nb_component(optriggers) 1
#---------------------------------------------------------------------------------------
#  Auto-Kicking for Begging with 30 seconds on Joining
set nb_component(nobeg) 0
nb_set L3utenant nb_component(nobeg) 1
  set sendbeggermsg "Check the sites first! THEN \(if you can't find it\) ask"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set begwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set begbantime 0
# No spaces are allowed in the triggers!!!
set begtriggers {
	*anyone?have*
	*looking?for*
	*who?has*
	*where?can?i?find*
	*where?can?i?get*
	*anyone?got*
	*anybody?got*
	*if?you?can?help*
	*ne1?have*
	*ne1?got*
	*any1?have*
	*who?has*
	*help?me?find*
	*any1?got*
	*i?need*
	*need?to?find*
	*msg?me*
	*where?can?i*
}
#---------------------------------------------------------------------------------------
#  Auto-Banning XDCC/TDCC Bots
set nb_component(noxdcc) 0
nb_set L3utenant nb_component(noxdcc) 1
  set xdccbanmsg "Should have read the rules! GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set xdccwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set xdccbantime 60
# No spaces are allowed in the triggers!!!
set xdcctriggers {
	*xdcc?send*
	*dcc?server*trigger*
	*dcc?server*ctcp*
	*file?server?online*
	*file?server*no?ratio*
	*\(ftp?online\)*
	*ftp*no?ratio*
	*server*online*trigger*
	*xxx*trigger*
	*tdcc*
	*fserve*online*
	*fserve*ctcp*
	*fserve*xdcc*
	*join*xxx*
	*napster?running?on*servers*
	*file?server*allowed*note*
	*file?server*address*note*
	*file?server*trigger*
}
#---------------------------------------------------------------------------------------
#  Monitoring and Auto-Banning Onjoins/Onparts (same as noSPAM, but with onjoin support)
set nb_component(noonjoin) 0
nb_set C4ptain nb_component(noonjoin) 1
# No spaces are allowed in the triggers!!!
  set invitekickmsg "Take your invite shit and GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set spamwarnings 0
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set spambantime 1
set spamtriggers {
	*guest*
	*xxx*
	*porn*
	*www.*
	*.com*
	*.net*
	*.org*
	*.cc*
	*invite*
	*http://*
	*ftp://*
	*free*
	*join*
	*join?#*
}
#---------------------------------------------------------------------------------------
#  Monitoring and Auto-Banning of Mass DCC's (virus spreading)
set nb_component(novirii) 1
#nb_set G3neral nb_component(novirii) 1
#---------------------------------------------------------------------------------------
#  Monitoring for SPAM and Mass MSG'ing and Auto-Banning (triggers are same as noonjoin)
set nb_component(nospam) 0
nb_set L3utenant nb_component(nospam) 1
#---------------------------------------------------------------------------------------
#  Auto-Banning of SPAM-type recruiters
set nb_component(norecruit) 0
nb_set L3utenant nb_component(norecruit) 1
  set recruitkickmsg "Recruiters are Not allowed here! GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set recruitwarnings 0
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set recruitbantime 1
# No spaces are allowed in the triggers!!!
set recruittriggers {  
	*T3*upload*divx*
	*T3*upload*vcd*
	*cable*upload*vcd*
	*looking*for*connection*
	*http://*cheap*
	*http://*check*
	*http://*free*
	*www.*cheap*
	*www.*check*
	*www.*free*
	*looking*for*T3*contact*
	*looking*for*cable*contact*
	*www.*xxx*
	*www.*fuck*
	*www.*porn*
	*www.*sex*
	*http://*xxx*
	*http://*fuck*
	*http://*porn*
	*http://*sex*
	*looking*for*join*
	*looking*for*cable*me*
	*looking*for*cable*want*
}
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using annoying script ads in the channel
set nb_component(noscriptads) 0
nb_set L3utenant nb_component(noscriptads) 1
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set adwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set adbantime 2
# No spaces are allowed in the triggers!!!
set annoytriggers {
	*po?aris?irc*
	*jpolaris*
	*is*away*duration*
	**i*-*n*-*v*-*i*-*s*-*i*-*o*-*n**
	*polaris??e*
	*polaris?2k*
	*\003*\003*\003*
	*\002*\002*\002*\002*
}
  set publicscriptadmsg "Hint: Colors are NOT cool, Nor are script ads"
# No spaces are allowed in the triggers!!!
set annoyactiontriggers {
	*\003*\003*\003*\003*
}
  set ctcpscriptadmsg "Hint: Bold is NOT cool, Nor are script ads"
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using ! or @ triggers
set nb_component(notriggers) 0
nb_set L3utenant nb_component(notriggers) 1
  set triggerkickmsg "No !/@ triggers here! '/CTCP M0r0n Rules' for Rules"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set triggerwarnings 3
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set triggerbantime 0
set triggertriggers {
	!find*
	@find*
	!list*
	@list*
	@ftp*
	!search*
	@search*
	@@*
	!locate*
	@locate*
	\\?locate*
	\\?rules*
	!rules*
	@rules*
}
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using excessive !!!!!!!!!!!'s and/or ??????????'s
set nb_component(noannoy) 0
nb_set L3utenant nb_component(noannoy) 1
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set annoywarnings 3
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set annoybantime 0
#---------------------------------------------------------------------------------------
#  Auto-Sending of customizable text on a timer (repeating) (message 1)
#  (Delay is in minutes)
set nb_component(timedmsg) 0
nb_set G3neral nb_component(timedmsg) 1
  set timedmsg1active 1
  set timed_msg1 "I am lame for not being setup correctly by my owner!!"
  set timer_chan1 "#Lamer"
  set timedmsgdelay1 "11"

#  Auto-Sending of customizable text on a timer (repeating) (message 2)
#  (Delay is in minutes)
  set timedmsg2active 1
  set timed_msg2 "I am lame for not being setup correctly by my owner!!"
  set timer_chan2 "#Lamer"
  set timedmsgdelay2 "8"
#---------------------------------------------------------------------------------------
set nb_component(rulesend) 1
#nb_set G3neral nb_component(rulesend) 1
#  Auto-Sending of channel rules upon CTCP request
  set autosendrules 1
  #the trigger below MUST BE CAPS TO WORK
  set rulestrigger "RULES"

#  Auto-Sending of customizable text upon CTCP request
  set autosendmisctext 1
  #the trigger below MUST BE CAPS TO WORK
  set misctexttrigger "SERVING"
#---------------------------------------------------------------------------------------

==> complete_channel_admin1.14_netbots_ed.zip: netset.tcl <==

# Additions by Loki`

# CCA Script Add-on
#---------------------------------------------------------------------------------------
# The channel(s) your bot will monitor (eg "#lamers #mychan #LokiRules #antilame"
  set approved_chans "#Lamer #FTP4Warez #TCL #Egghelp"
# The channel(s) your bot will monitor for onjoins
  set spamcheck_chans "#Lamer"
# The channel that auto-perm ban announcements will be made in
  set pbannounce "#Lamer"
# If you know the numbers of diffr colors, put them here (for messages and stuff)
  set color1loki 5
  set color2loki 4
#---------------------------------------------------------------------------------------
# Base modules (used by all scripts below)
set nb_component(ccasbase) 1
#nb_set MyBotNick nb_component(ccasbase) 1
#---------------------------------------------------------------------------------------
#  Enable OP Channel Triggers (!kb, !perm, !addserv, !adduser...)
set nb_component(optriggers) 0
nb_set MyBotNick nb_component(optriggers) 1
# Set the channels that advanced op triggers are NOT allowed in (!addop, !chattr, !deluser,..)
   set noadvtriggers "#Lamer #FTP4Warez"
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using annoying script ads in the channel
set nb_component(noscriptads) 0
nb_set MyBotNick nb_component(noscriptads) 1
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set adwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set adbantime 2
# No spaces are allowed in the triggers!!!
set annoytriggers {
	po?aris?irc
	jpolaris
	is*away*duration
	*i*-*n*-*v*-*i*-*s*-*i*-*o*-*n*
	polaris??e
	polaris?2k
	\003*\003*\003
	\0032*\003
	\0033*\003
	\0034*\003
	\0035*\003
	\0036*\003
	\0037*\003
	\0038*\003
	\0039*\003
	\00310*\003
	\00311*\003
	\00312*\003
	\002*\002*\002*\002
}
  set publicscriptadmsg "Hint: Colors are NOT cool, Nor are script ads"
# No spaces are allowed in the triggers!!!
set annoyactiontriggers {
	\003*\003*\003*\003
	\0032*\003
	\0033*\003
	\0036*\003
	\0037*\003
	\0038*\003
	\0039*\003
	\00310*\003
	\00311*\003
	\00312*\003
}
  set ctcpscriptadmsg "Hint: Colors are NOT cool, Nor are script ads"
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using ! or @ triggers
set nb_component(notriggers) 0
nb_set MyBotNick nb_component(notriggers) 1
  set triggerkickmsg "No !/@ triggers here! '/CTCP M0r0n Rules' for Rules"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set triggerwarnings 3
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set triggerbantime 0
set triggertriggers {
	!find
	@find
	!list
	@list
	@ftp
	!search
	@search
	@@
	!locate
	@locate
	\\?locate
	\\?rules
	!rules
	@rules
}
#---------------------------------------------------------------------------------------
#  Auto-Kicking of people using excessive !!!!!!!!!!!'s and/or ??????????'s
set nb_component(noannoy) 0
nb_set MyBotNick nb_component(noannoy) 1
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set annoywarnings 3
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set annoybantime 0
#---------------------------------------------------------------------------------------
#  Auto-Kicking for Begging with 30 seconds on Joining
set nb_component(nobeg) 0
nb_set MyBotNick nb_component(nobeg) 1
   set sendbeggermsg "Check the sites first! THEN \(if you can't find it\) ask"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set begwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set begbantime 0
# No spaces are allowed in the triggers!!!
set begtriggers {
	anyone?have
	looking?for
	who?has
	where?can?i?find
	where?can?i?get
	anyone?got
	anybody?got
	if?you?can?help
	ne1?have
	ne1?got
	any1?have
	who?has
	help?me?find
	any1?got
	i?need
	need?to?find
	msg?me
	where?can?i
}
#---------------------------------------------------------------------------------------
#  Auto-Banning for 'Revolving Door' (Join/Part with 5 seconds)
set nb_component(nojoinpart) 0
nb_set MyBotNick nb_component(nojoinpart) 1
   set jpmsg "Revolving Door - If ur gunna join, join!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set jpwarnings 4
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set jpbantime 2
# Set exempt channels here (bans will not be placed)
   set nojpchannels "#Lamer #TCL"
#---------------------------------------------------------------------------------------
#  Auto-Banning XDCC/TDCC Bots
set nb_component(noxdcc) 0
nb_set MyBotNick nb_component(noxdcc) 1
  set xdccbanmsg "Should have read the rules! GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set xdccwarnings 2
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set xdccbantime 60
# No spaces are allowed in the triggers!!!
set xdcctriggers {
	xdcc?send
	dcc?server*trigger
	dcc?server*ctcp
	file?server?online
	file?server*no?ratio
	\(ftp?online\)
	ftp*no?ratio
	server*online*trigger
	xxx*trigger
	tdcc
	fserve*online
	fserve*ctcp
	fserve*xdcc
	join*xxx
	napster?running?on*servers
	file?server*allowed*note
	file?server*address*note
	file?server*trigger
}
#---------------------------------------------------------------------------------------
#  Monitoring and Auto-Banning Onjoins/Onparts (same as noSPAM, but with onjoin support)
set nb_component(noonjoin) 0
nb_set MyBotNick nb_component(noonjoin) 1
# No spaces are allowed in the triggers!!!
  set invitekickmsg "Take your invite shit and GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set spamwarnings 0
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set spambantime 1
set spamtriggers {
	guest
	xxx
	porn
	www.
	.com
	.net
	.org
	.cc
	i*n*v*i*t*e
	h*t*t*p
	h*t*t*p*w*w*w
	ftp
	free
	join
}
#---------------------------------------------------------------------------------------
#  Monitoring and Auto-Banning of Mass DCC's (virus spreading)
set nb_component(novirii) 1
#nb_set MyBotNick nb_component(novirii) 1
#---------------------------------------------------------------------------------------
#  Monitoring for SPAM and Mass MSG'ing and Auto-Banning (triggers are same as noonjoin)
set nb_component(nospam) 0
nb_set MyBotNick nb_component(nospam) 1
#---------------------------------------------------------------------------------------
#  Auto-Banning of SPAM-type recruiters
set nb_component(norecruit) 0
nb_set MyBotNick nb_component(norecruit) 1
  set recruitkickmsg "Recruiters are Not allowed here! GO AWAY!!"
# Set the amount of warnings here (0 - 10) (0 for instant perm ban)
   set recruitwarnings 0
# Set number of minutes for warning bans (1 - 99999999) (0 for kick only)
   set recruitbantime 1
# No spaces are allowed in the triggers!!!
set recruittriggers {  
	T3*upload*divx
	T3*upload*vcd
	cable*upload*vcd
	looking*for*connection
	http*xxx
	http*fuck
	http*porn
	http*sex
	http*cheap
	http*check
	http*free
	www.*cheap
	www.*check
	www.*free
	www.*xxx
	www.*fuck
	www.*porn
	www.*sex
	looking*for*T3*contact
	looking*for*cable*contact
	looking*for*join
	looking*for*cable*me
	looking*for*cable*want
}
#---------------------------------------------------------------------------------------
#  Auto-Sending of customizable text on a timer (repeating) (message 1)
#  (Delay is in minutes)
set nb_component(timedmsg) 0
nb_set MyBotNick nb_component(timedmsg) 1
  set timedmsg1active 1 ;# (0 for disabled)
  set timed_msg1 "I am lame for not being setup correctly by my owner!!"
  set timer_chan1 "#Lamer"
  set timedmsgdelay1 "11"

#  Auto-Sending of customizable text on a timer (repeating) (message 2)
#  (Delay is in minutes)
  set timedmsg2active 1 ;# (0 for disabled)
  set timed_msg2 "I am lame for not being setup correctly by my owner!!"
  set timer_chan2 "#Lamer"
  set timedmsgdelay2 "8"
#---------------------------------------------------------------------------------------
#  Auto-Sending of customizable advertisement on a timer (repeating) (disabled by default to stop annoyances)
# set component to 1 to activate.. BE SURE to set this up correctly, or you will be VERY annoyed
set nb_component(timedadv) 0
nb_set Pr1vate nb_component(timedadv) 0
# Delay in minutes for advertising message to be displayed in the channels
  set timed_advdelay 2
# Set the message here
  set timed_adv "My owner is running Complete Channel Admin Script (CCAS) v1.14 by Loki of #FTP4Warez Download me for your channel @ ftp://ftp.eggheads.org/pub/eggdrop/scripts/1.6/complete_channel_admin1.14.zip"
# Set channels the bot will NOT advertise in
  set noadchannels "#FTP4Warez #Egghelp"
# Set the topic to be placed in the advertising channels (assuming the bot gets ops there)
  set adv_topic "CCAS - Get it @ ftp://ftp.eggheads.org/pub/eggdrop/scripts/1.6/complete_channel_admin1.12.zip"
#---------------------------------------------------------------------------------------
#  Auto-Sending of RULES (or whatever) on a trigger
set nb_component(rulesend) 1
#nb_set MyBotNick nb_component(rulesend) 1
#  Auto-Sending of channel rules upon CTCP request (0 for disable)
  set autosendrules 1
  #the trigger below MUST BE CAPS TO WORK
  set rulestrigger "RULES"

#  Auto-Sending of customizable text upon CTCP request (0 for disable)
  set autosendmisctext 1
  #the trigger below MUST BE CAPS TO WORK
  set misctexttrigger "SERVING"
#---------------------------------------------------------------------------------------
